<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt_LT">
<context>
    <name>Clipboard</name>
    <message>
        <location filename="../src/clipboard.cpp" line="79"/>
        <source>Copy color %1 to clipboard</source>
        <translation>Spalva %1 nukopijuota į iškarpinę</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main.cpp" line="58"/>
        <source>Deepin Picker is a quick and easy screen color picking tool. RGB and HEX codes are obtained on click and auto saved to the clipboard.</source>
        <translation>Deepin parinkiklis yra greitas ir lengvas naudoti ekrano spalvos parinkimo įrankis. Spustelėjus yra gaunami RGB ir HEX kodai, kurie yra automatiškai įrašomi į iškarpinę.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="80"/>
        <source>Deepin Picker</source>
        <translation>Deepin parinkiklis</translation>
    </message>
</context>
</TS>
